@@ -2,8 +2,7 @@
 extern crate lazy_static;
 
 pub use cmd::lint;
-pub use model::CONFIG_KEY_PREFIX;
-pub use model::{Code, Error, Lint, LintError, Lints, Problem};
+pub use model::{Code, Error, Lint, LintError, Lints, Problem, CONFIG_KEY_PREFIX};
 
 mod checks;
 mod cmd;
